<?php
session_start();

// Check if the user is not logged in
if (!isset($_SESSION['loggedin']) || $_SESSION['loggedin'] !== true) {
    header("Location: login.php");
    exit;
}

// Database connection
$servername = "localhost";
$username = "msrprox1_hot";
$password = "Sha@bbir..1";
$dbname = "msrprox1_hot";

$conn = new mysqli($servername, $username, $password, $dbname);

if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Handle form submission for generating QR codes
if (isset($_POST['submit'])) {
    $name = htmlspecialchars($_POST['name']);
    $mnemonic = htmlspecialchars($_POST['mnemonic']);

    // Generate QR code
    require_once('phpqrcode/qrlib.php');
    $qrCodeDir = 'qr_codes/';
    if (!is_dir($qrCodeDir)) {
        mkdir($qrCodeDir, 0777, true);
    }
    $qrCodeFile = $qrCodeDir . md5($mnemonic) . '.png';
    QRcode::png($mnemonic, $qrCodeFile);

    // Insert data into the database
    $stmt = $conn->prepare("INSERT INTO qr_entries (name, mnemonic, qr_code, date) VALUES (?, ?, ?, NOW())");
    if ($stmt === false) {
        die("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param("sss", $name, $mnemonic, $qrCodeFile);
    $stmt->execute();
    $stmt->close();

    header("Location: " . $_SERVER['PHP_SELF']);
    exit();
}

// Handle search functionality
$searchTerm = '';
$entries = [];
if (isset($_POST['search'])) {
    $searchTerm = htmlspecialchars($_POST['search']);
    $query = "SELECT id, name, mnemonic, qr_code, date FROM qr_entries WHERE name LIKE ? OR mnemonic LIKE ?";
    $stmt = $conn->prepare($query);
    if ($stmt === false) {
        die("Prepare failed: " . $conn->error);
    }
    $searchWildcard = "%$searchTerm%";
    $stmt->bind_param("ss", $searchWildcard, $searchWildcard);
    $stmt->execute();

    $stmt->bind_result($id, $name, $mnemonic, $qrCode, $date);
    while ($stmt->fetch()) {
        $entries[] = [
            'id' => $id,
            'name' => $name,
            'mnemonic' => $mnemonic,
            'qr_code' => $qrCode,
            'date' => $date,
        ];
    }
    $stmt->close();
} else {
    $result = $conn->query("SELECT id, name, mnemonic, qr_code, date FROM qr_entries ORDER BY date DESC");
    if ($result === false) {
        die("Query failed: " . $conn->error);
    }
    while ($row = $result->fetch_assoc()) {
        $entries[] = $row;
    }
}

// Handle delete functionality
if (isset($_POST['delete'])) {
    $id = intval($_POST['id']);

    $query = "SELECT qr_code FROM qr_entries WHERE id = ?";
    $stmt = $conn->prepare($query);
    if ($stmt === false) {
        die("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $stmt->bind_result($qrCodeFile);
    $stmt->fetch();
    $stmt->close();

    if (file_exists($qrCodeFile)) {
        unlink($qrCodeFile);
    }

    $stmt = $conn->prepare("DELETE FROM qr_entries WHERE id = ?");
    if ($stmt === false) {
        die("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $stmt->close();

    $result = $conn->query("SELECT COUNT(*) as count FROM qr_entries");
    $row = $result->fetch_assoc();
    if ($row['count'] == 0) {
        $conn->query("ALTER TABLE qr_entries AUTO_INCREMENT = 1");
    }

    header("Location: " . $_SERVER['PHP_SELF']);
    exit();
}

// Handle update functionality
if (isset($_POST['update'])) {
    $id = intval($_POST['id']);
    $name = htmlspecialchars($_POST['name']);
    $mnemonic = htmlspecialchars($_POST['mnemonic']);

    require_once('phpqrcode/qrlib.php');
    $qrCodeDir = 'qr_codes/';
    $qrCodeFile = $qrCodeDir . md5($mnemonic) . '.png';
    QRcode::png($mnemonic, $qrCodeFile);

    $stmt = $conn->prepare("UPDATE qr_entries SET name = ?, mnemonic = ?, qr_code = ?, date = NOW() WHERE id = ?");
    if ($stmt === false) {
        die("Prepare failed: " . $conn->error);
    }
    $stmt->bind_param("sssi", $name, $mnemonic, $qrCodeFile, $id);
    $stmt->execute();
    $stmt->close();

    header("Location: " . $_SERVER['PHP_SELF']);
    exit();
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>QR Code Generator</title>
    <link rel="stylesheet" href="styles.css">
</head>
<body>
    <div class="container">
        <!-- Logout Button -->
        <form action="logout.php" method="POST">
            <input type="submit" value="Logout" class="btn btn-logout">
        </form>
        
        <!-- Export Button -->
        <form method="POST" action="export.php" style="margin-top: 20px;">
            <input type="submit" value="Export to Excel" class="btn btn-export">
        </form>

        <h1>QR Code Generator</h1>

        <!-- Form to generate QR code -->
        <form method="POST" action="">
            <input type="text" name="name" placeholder="Enter name" required>
            <input type="text" name="mnemonic" placeholder="Enter mnemonic (12 or 14 words)" required>
            <input type="submit" name="submit" value="Generate QR Code">
        </form>

        <!-- Search form -->
        <form method="POST" action="">
            <input type="text" name="search" placeholder="Search by name or mnemonic" value="<?php echo htmlspecialchars($searchTerm); ?>">
            <input type="submit" value="Search">
        </form>

        <table id="dataTable">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Name</th>
                    <th>Mnemonic</th>
                    <th>QR Code</th>
                    <th>Date</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($entries as $entry): ?>
                    <tr>
                        <td><?php echo htmlspecialchars($entry['id']); ?></td>
                        <td><?php echo htmlspecialchars($entry['name']); ?></td>
                        <td>
                            <?php echo htmlspecialchars($entry['mnemonic']); ?>
                            <button class="btn btn-copy" onclick="copyMnemonic('<?php echo htmlspecialchars($entry['mnemonic']); ?>')">Copy</button>
                        </td>
                        <td>
                            <img src="<?php echo htmlspecialchars($entry['qr_code']); ?>" alt="QR Code" style="width: 100px; cursor: pointer;" onclick="openQRCodePopup('<?php echo htmlspecialchars($entry['qr_code']); ?>')">
                        </td>
                        <td><?php echo htmlspecialchars($entry['date']); ?></td>
                        <td>
                            <button class="btn btn-edit" onclick="openEditForm(<?php echo htmlspecialchars($entry['id']); ?>, '<?php echo htmlspecialchars($entry['name']); ?>', '<?php echo htmlspecialchars($entry['mnemonic']); ?>')">Edit</button>
                            <form method="POST" action="" style="display:inline;">
                                <input type="hidden" name="id" value="<?php echo htmlspecialchars($entry['id']); ?>">
                                <input type="submit" name="delete" value="Delete" class="btn btn-delete">
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <!-- Edit Form Modal -->
    <div id="editForm" class="modal">
        <form method="POST" action="">
            <input type="hidden" name="id" id="editId">
            <input type="text" name="name" id="editName" placeholder="Enter name" required>
            <input type="text" name="mnemonic" id="editMnemonic" placeholder="Enter mnemonic (12 or 14 words)" required>
            <input type="submit" name="update" value="Update">
            <button type="button" onclick="closeEditForm()">Cancel</button>
        </form>
    </div>

    <!-- QR Code Popup -->
    <div id="qrPopup" class="qr-popup">
        <img id="popupImg" src="" alt="QR Code">
        <button onclick="closeQRCodePopup()">Cancel</button>
    </div>

    <script src="script.js"></script>
</body>
</html>
